<a id="mypy-boto3-rbin"></a>

# mypy-boto3-rbin

[![PyPI - mypy-boto3-rbin](https://img.shields.io/pypi/v/mypy-boto3-rbin.svg?color=blue)](https://pypi.org/project/mypy-boto3-rbin)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-rbin.svg?color=blue)](https://pypi.org/project/mypy-boto3-rbin)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-rbin?color=blue)](https://pypistats.org/packages/mypy-boto3-rbin)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.RecycleBin 1.20.46](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/rbin.html#RecycleBin)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-rbin docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-rbin](#mypy-boto3-rbin)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `RecycleBin`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `RecycleBin` service.

```bash
python -m pip install boto3-stubs[rbin]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[rbin]` in your environment:
  `python -m pip install 'boto3-stubs[rbin]'`

Both type checking and auto-complete should work for `RecycleBin` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto3-stubs[rbin]` in your environment:
  `python -m pip install 'boto3-stubs[rbin]'`

Both type checking and auto-complete should work for `RecycleBin` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[rbin]` in your environment:
  `python -m pip install 'boto3-stubs[rbin]'`
- Run `mypy` as usual

Type checking should work for `RecycleBin` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto3-stubs[rbin]` in your environment:
  `python -m pip install 'boto3-stubs[rbin]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `RecycleBin` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`RecycleBinClient` provides annotations for `boto3.client("rbin")`.

```python
import boto3

from mypy_boto3_rbin import RecycleBinClient

client: RecycleBinClient = boto3.client("rbin")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: RecycleBinClient = session.client("rbin")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_rbin.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_rbin import RecycleBinClient
from mypy_boto3_rbin.paginator import (
    ListRulesPaginator,
)

client: RecycleBinClient = boto3.client("rbin")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
```

<a id="literals"></a>

### Literals

`mypy_boto3_rbin.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_rbin.literals import (
    ListRulesPaginatorName,
    ResourceTypeType,
    RetentionPeriodUnitType,
    RuleStatusType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ListRulesPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_rbin.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_rbin.type_defs import (
    CreateRuleRequestRequestTypeDef,
    CreateRuleResponseTypeDef,
    DeleteRuleRequestRequestTypeDef,
    GetRuleRequestRequestTypeDef,
    GetRuleResponseTypeDef,
    ListRulesRequestRequestTypeDef,
    ListRulesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    ResourceTagTypeDef,
    ResponseMetadataTypeDef,
    RetentionPeriodTypeDef,
    RuleSummaryTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateRuleRequestRequestTypeDef,
    UpdateRuleResponseTypeDef,
)

def get_structure() -> CreateRuleRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-rbin` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-rbin docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rbin/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
